@@ -2,44 +2,41 @@
 knitr::opts_chunk$set(collapse = TRUE)
 
 ## ------------------------------------------------------------------------
-library(oceanis)
-donnees_monoloc <- lecture_fichier(file = system.file("data/donnees_monoloc.rda", package = "oceanis"))
+donnees_monoloc <- rio::import(file = system.file("data/donnees_monoloc.rda", package = "oceanis"))
 
 ## ---- fig.width = 5------------------------------------------------------
 library(oceanis)
+
 # chargement des donnees
-donnees_monoloc <- lecture_fichier(file = system.file("data/donnees_monoloc.rda", package = "oceanis"))
+donnees_monoloc <- rio::import(file = system.file("data/donnees_monoloc.rda", package = "oceanis"))
 # visualisation de la distribution de la variable VAR_AN_MOY
 distrib_variable(data = donnees_monoloc ,varRatio = "VAR_AN_MOY", nbClasses = 4)
 
 ## ----fondCarte, fig.height = 3, fig.width = 3----------------------------
-library(sf)
-
 # chemin du fond de carte .shp
 path_to_shp <- system.file("extdata","dep_francemetro_2018.shp", package = "oceanis")
 # import de l'objet sf
-depm <- st_read(dsn = path_to_shp, quiet = TRUE)
+depm <- sf::st_read(dsn = path_to_shp, quiet = TRUE)
 
 # visualisation de la geometrie
 # modification des marges
 par(mai = c(0,0,0,0))
 # contour des departements de France metropolitaine
-plot(st_geometry(depm))
+plot(sf::st_geometry(depm))
 
 ## ----zonageAFacon, fig.height = 5, fig.width = 5-------------------------
 library(oceanis)
-library(sf)
 
 # chargement des donnees :
 # donnees a facon avec variable de regroupement (ZE2010)
-donnees_a_facon <- lecture_fichier(file = system.file("data/donnees_a_facon.rda", package = "oceanis"))
+donnees_a_facon <- rio::import(file = system.file("data/donnees_a_facon.rda", package = "oceanis"))
 # fond communal des departements 13, 30, 83 et 84
-com_dep_13_30_83_84 <- lecture_fichier(file = system.file("data/com_dep_13_30_83_84.rda", package = "oceanis"))
+com_dep_13_30_83_84 <- rio::import(file = system.file("data/com_dep_13_30_83_84.rda", package = "oceanis"))
 
 # chemin du fond de carte .shp
 path_to_shp <- system.file("extdata","dep_francemetro_2018.shp", package = "oceanis")
 # import en objet sf
-depm <- st_read(dsn = path_to_shp, quiet = TRUE, stringsAsFactors = FALSE)
+depm <- sf::st_read(dsn = path_to_shp, quiet = TRUE, stringsAsFactors = FALSE)
 
 # creation du zonage des zones d'emploi des Bouches-du-Rhone (partie entiere des ze)
 ze13etplus <- zonage_a_facon(fondMaille = com_dep_13_30_83_84, groupe = donnees_a_facon,
@@ -54,68 +51,63 @@ ze13 <- zonage_a_facon(fondMaille = com_dep_13_30_83_84, groupe = donnees_a_faco
 # modification des marges
 par(mai = c(0,0,0,0))
 # fond des ze des Bouches-du-Rhone en 1er pour fixer le niveau de zoom, en bleu
-plot(st_geometry(ze13etplus), col = "powderblue", border = "transparent")
+plot(sf::st_geometry(ze13etplus), col = "powderblue", border = "transparent")
 # fond de la partie tronquee des ze des Bouches-du-Rhone, en rouge
-plot(st_geometry(ze13), col = "lightsalmon", border = "transparent", add = TRUE)
+plot(sf::st_geometry(ze13), col = "lightsalmon", border = "transparent", add = TRUE)
 # contour des communes
-plot(st_geometry(com_dep_13_30_83_84), col = "transparent", border = "lavender", add = TRUE)
+plot(sf::st_geometry(com_dep_13_30_83_84), col = "transparent", border = "lavender", add = TRUE)
 # contour de la partie tronquee des ze des Bouches-du-Rhone, en rouge
-plot(st_geometry(ze13), col = "transparent", border = "indianred", lwd = 3, add = TRUE)
+plot(sf::st_geometry(ze13), col = "transparent", border = "indianred", lwd = 3, add = TRUE)
 # contour des ze des Bouches-du-Rhone, en bleu
-plot(st_geometry(ze13etplus), col = "transparent", border = "steelblue", lwd = 3, add = TRUE)
+plot(sf::st_geometry(ze13etplus), col = "transparent", border = "steelblue", lwd = 3, add = TRUE)
 
 ## ----shinyRondsAnalyseClasses, eval = FALSE------------------------------
 #  library(oceanis)
-#  library(sf)
 #  library(shiny)
 #  
 #  # chargement des donnees
-#  donnees_monoloc <- lecture_fichier(file = system.file("data/donnees_monoloc.rda", package = "oceanis"))
+#  donnees_monoloc <- rio::import(file = system.file("data/donnees_monoloc.rda", package = "oceanis"))
 #  
 #  # import du fond des departements
-#  depm <- st_read(dsn = system.file("extdata","dep_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+#  depm <- sf::st_read(dsn = system.file("extdata","dep_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 #  # import du fond des regions
-#  regm <- st_read(dsn = system.file("extdata","reg_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+#  regm <- sf::st_read(dsn = system.file("extdata","reg_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 #  # import du fond de France metropolitaine
-#  fram <- st_read(dsn = system.file("extdata","francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+#  fram <- sf::st_read(dsn = system.file("extdata","francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 #  
 #  shiny_classes_ronds(data = donnees_monoloc, fondMaille = depm[depm$reg %in% c("93","94"),], fondMailleElargi = depm, fondContour = fram, fondSuppl = regm, idData = "COD_DEP",varVolume = "POP_2015", varRatio = "VAR_AN_MOY")
 
 ## ----shinyJoignantes, eval = FALSE---------------------------------------
 #  library(oceanis)
-#  library(sf)
 #  library(shiny)
 #  
 #  # chargement des donnees
-#  donnees_biloc <- lecture_fichier(file = system.file("data/donnees_biloc.rda", package = "oceanis"))
+#  donnees_biloc <- rio::import(file = system.file("data/donnees_biloc.rda", package = "oceanis"))
 #  
 #  # import du fond des regions
-#  regm <- st_read(dsn = system.file("extdata","reg_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+#  regm <- sf::st_read(dsn = system.file("extdata","reg_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 #  # import du fond des departements
-#  depm <- st_read(dsn = system.file("extdata","dep_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+#  depm <- sf::st_read(dsn = system.file("extdata","dep_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 #  # import du fond de France metropolitaine
-#  fram <- st_read(dsn = system.file("extdata","francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+#  fram <- sf::st_read(dsn = system.file("extdata","francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 #  
 #  shiny_joignantes(data = donnees_biloc, fondMaille = regm, typeMaille = "REG", fondContour = fram, fondSuppl = depm, idDataDepart = "REG_DEPART", idDataArrivee = "REG_ARRIVEE", varFlux = "MIGR", decalageAllerRetour = 10, decalageCentroid = 20)
 
 ## ----leafletAnalyseClassesRonds, fig.height = 6, fig.width = 9-----------
 library(oceanis)
-library(sf)
 library(leaflet)
 
 # chargement des donnees
-donnees_monoloc <- lecture_fichier(file = system.file("data/donnees_monoloc.rda", package = "oceanis"))
+donnees_monoloc <- rio::import(file = system.file("data/donnees_monoloc.rda", package = "oceanis"))
 
 # import du fond des departements
-depm <- st_read(dsn = system.file("extdata","dep_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+depm <- sf::st_read(dsn = system.file("extdata","dep_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 # import du fond des regions
-regm <- st_read(dsn = system.file("extdata","reg_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+regm <- sf::st_read(dsn = system.file("extdata","reg_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 
 # affichage de la carte
 map <- leaflet_ronds_classes(data = donnees_monoloc, fondMaille = depm[depm$reg=="93",], fondMailleElargi = depm, fondSuppl = regm, idData = "COD_DEP", varVolume = "POP_2015", varRatio = "VAR_AN_MOY")
 
-map
-
 # affichage du rayon du rond le plus grand en metres
 rayon_ronds(map)
 
@@ -125,29 +117,21 @@ map <- leaflet_ronds_classes(data = donnees_monoloc, fondMaille = depm[depm$reg
 # affichage du rapport du rond le plus grand, a recuperer pour permettre la comparaison de plusieurs cartes
 rapport_ronds(map)
 
-map
-
 # ajout de la legende des ronds (position par defaut)
 map <- add_legende_ronds(map = map, titre = "Population en 2015", zoom = 6)
 # ajout de la legende des classes (position par defaut)
 map <- add_legende_classes(map = map, titre = "Variation ann.moy. 2010-2015", zoom = 6)
 
-map
-
 # modification de la position de la legende des ronds et du niveau de zoom
 map <- add_legende_ronds(map = map, titre = "Population en 2015", lng = 8, lat = 44, zoom = 8)
 # modification de la position de la legende des classes et du niveau de zoom
 map <- add_legende_classes(map = map, titre = "Variation ann.moy. 2010-2015", lng = 7.5, lat = 43.5, zoom = 8)
 
-map
-
 # ajout d'une source a la carte
 map <- add_source(map = map, source = "Source : INSEE - RP2016")
 # ajout d'un titre a la carte
 map <- add_titre(map = map, titre = "Population des departements de la region Provence-Alpes-Cote d'Azur en 2015 et son evolution depuis 2010")
 
-map
-
 # affichage de la palette par defaut
 recup_palette(stylePalette = "defaut")
 
@@ -159,33 +143,26 @@ map <- set_couleur_ronds(map = map, colBorder = "grey")
 # modification du style de la palette
 map <- set_couleur_classes(map = map, stylePalette = "InseePremiere")
 
-map
-
 # modification de l'opacite de la representation elargie
 map <- set_opacite_elargi(map, opacite = 0.3)
 
-map
-
 # ajout d'un fond OpenStreetMap
 map <- add_fond_osm(map)
 
-map
-
 ## ----plotSaphirs, fig.height = 6, fig.width = 7--------------------------
 library(oceanis)
-library(sf)
 
 # chargement des donnees
-donnees_biloc_saphirs <- lecture_fichier(file = system.file("data/donnees_biloc_saphirs.rda", package = "oceanis"))
+donnees_biloc_saphirs <- rio::import(file = system.file("data/donnees_biloc_saphirs.rda", package = "oceanis"))
 
 # import du fond des regions
-regm <- st_read(dsn = system.file("extdata","reg_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+regm <- sf::st_read(dsn = system.file("extdata","reg_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 # import du fond de France metropolitaine
-fram <- st_read(dsn = system.file("extdata","francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+fram <- sf::st_read(dsn = system.file("extdata","francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 # import du fond des pays
-paysm <- st_read(dsn = system.file("extdata","paysf_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+paysm <- sf::st_read(dsn = system.file("extdata","paysf_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 # import du fond de mer
-merm <- st_read(dsn = system.file("extdata","merf_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+merm <- sf::st_read(dsn = system.file("extdata","merf_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 
 # affichage de la carte
 fond_saphirs <- plot_saphirs(data = donnees_biloc_saphirs, fondMaille = regm, typeMaille = "REG", idDataDepart = "REG_DEPART", idDataArrivee = "REG_ARRIVEE", varFlux = "MIGR", direction = "Ent", titreLeg = "Entrees", xLeg = 1100000, yLeg = 6470000, titreCarte = "Migrations residentielles vers l'Ile-de-France", sourceCarte = "Source : INSEE - RP2016", colEntree = "#D2691E", colBorder = "transparent", colBorderMaille = "grey")
@@ -252,16 +229,15 @@ fond_saphirs <- plot_saphirs(data = donnees_biloc_saphirs, fondMaille = regm, fo
 
 ## ----exportQgis, eval = FALSE--------------------------------------------
 #  library(oceanis)
-#  library(sf)
 #  library(leaflet)
 #  
 #  # chargement des donnees
-#  donnees_monoloc <- lecture_fichier(file = system.file("data/donnees_monoloc.rda", package = "oceanis"))
+#  donnees_monoloc <- rio::import(file = system.file("data/donnees_monoloc.rda", package = "oceanis"))
 #  
 #  # import du fond des departements
-#  depm <- st_read(dsn = system.file("extdata","dep_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+#  depm <- sf::st_read(dsn = system.file("extdata","dep_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 #  # import du fond des regions
-#  regm <- st_read(dsn = system.file("extdata","reg_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
+#  regm <- sf::st_read(dsn = system.file("extdata","reg_francemetro_2018.shp", package = "oceanis"), quiet = TRUE, stringsAsFactors = FALSE)
 #  
 #  # affichage de la carte avec des rayons de ronds plus grands
 #  map <- leaflet_ronds_classes(data = donnees_monoloc, fondMaille = depm[depm$reg == "93",], fondMailleElargi = depm, fondSuppl = regm, idData = "COD_DEP", varVolume = "POP_2015", varRatio = "VAR_AN_MOY", rayonRond = 29000, rapportRond = NULL)
